OC.L10N.register(
    "files",
    {
    "Unknown error" : "غیر معروف خرابی",
    "Close" : "بند ",
    "Download" : "ڈاؤن لوڈ،",
    "Rename" : "نام بدلیں",
    "Delete" : "حذف کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "Files" : "فائلیں",
    "group" : "مجموعہ",
    "Name" : "اسم",
    "Settings" : "ترتیبات"
},
"nplurals=2; plural=(n != 1);");
